# -*- coding: iso-8859-1 -*-
# pylint: disable-msg=E0201
# pylint-version = 0.7.0
#
# Copyright 2005 Andr Malo or his licensors, as applicable
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
Testcases for svnmailer.browser.chora

:var _tests: The test classes
:type _tests: ``list``
"""
__author__    = "Andr Malo"
__docformat__ = "restructuredtext en"
__all__       = ['getSuite']

from svnmailer_test import base
_tests = []


#### Test Bases                                     ####
########################################################
class TestBase(base.TestBase):
    """ Base class for browser tests """
    LOAD_MODULES = (('_chora', 'svnmailer.browser.chora'),)

    def getInitialMocks(self):
        """ Returns the initially mocked modules """
        return [
            self._mock_svnmailer_browser_base(),
            self._mock_posixpath(),
        ]


#### Test Cases                                     ####
########################################################
class GeneratorTestCase(TestBase):
    """ svnmailer.browser.chora.Generator """
    PREFIX = "Generator"

    def test00general(self):
        """ Generator is a public _base.BaseGenerator """
        expected = self.mock['svnmailer.browser._base'].BaseGenerator
        result = self._chora.Generator

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failUnless(result.__name__ in self.public(self._chora),
            "Is not public")

    def test01initial(self):
        """ ._SESSIONNAME is properly set initially """
        self.mock.result = [self._chora.Generator._SESSIONNAME]
        self.expect(u"Horde")

    def test02createTemplate(self):
        """ ._createTemplate returns a Template """
        self.mock.posixpath.track = False
        inst = self._chora.Generator()
        self.mock.result.append(inst._createTemplate('foo', 'bar')._mocked)

        self.expect(
            'browser._base.BaseGenerator._createParsedUrl', 'foo',
            'browser._base.ParsedQuery.remove', [u'Horde', u'tr1', u'tr2'],
            'browser._base.Template.fromTemplates', 'foo', {
                'revision': ('bar', {
                    'remove': [u'r', u'r1', u'r2', u'ty', u'num', u'ws']}),
                'deleted': (u'co.php/BASE_PATH', {
                    'set': [(u'r', 'BASE_REVISION')],
                    'remove': [u'r1', u'r2', u'ty', u'num', u'ws']}),
                'deleted_dir': (u'bar/BASE_PATH/', {
                    'set': [(u'r', 'BASE_REVISION')],
                    'remove': [u'r1', u'r2', u'ty', u'num', u'ws']}),
                'added': (u'co.php/PATH', {
                    'set': [(u'r', 'REVISION')],
                    'remove': [u'r1', u'r2', u'ty', u'num', u'ws']}),
                'added_dir': (u'bar/PATH/', {
                    'set': [(u'r', 'REVISION')],
                    'remove': [u'r1', u'r2', u'ty', u'num', u'ws']}),
                'modified': (u'diff.php/PATH', {
                    'set': [(u'r1', 'BASE_REVISION'), (u'r2', 'REVISION')],
                    'remove': [u'r', u'p']}),
                'copied': (u'co.php/PATH', {
                    'set': [(u'r', 'REVISION')],
                    'remove': [u'r1', u'r2', u'ty', u'num', u'ws']}),
                },
                'Template'
            )

    def test03createTemplate(self):
        """ ._createTemplate passes AttibuteError """
        self.mock.error = 'browser.template.attr'
        inst = self._chora.Generator()

        self.failUnlessRaises(AttributeError,
            inst._createTemplate, 'foo', 'bar')

_tests.append(GeneratorTestCase)


#### Glue code                                      ####
########################################################
__all__.extend(_tests)

def getSuite():
    """ Returns the test suite for this module """
    return [_test.__name__ for _test in _tests]
