# -*- coding: iso-8859-1 -*-
# pylint: disable-msg=W0131,E0201,E0213,W0613,C0103,W0703,W0612,W0232
# pylint-version = 0.7.0
#
# Copyright 2004-2005 Andr Malo or his licensors, as applicable
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
Testcases for svnmailer.notifier.stdout

:var _tests: The test classes
:type _tests: ``list``
"""
__author__    = "Andr Malo"
__docformat__ = "restructuredtext en"
__all__       = ['getSuite']

import unittest
_tests = []


class importTestCase(unittest.TestCase):
    """ Importing svnmailer.notifier.stdout """

    def testImport(self):
        """ from svnmailer.notifier import stdout """
        try:
            from svnmailer.notifier import stdout
        except Exception, exc:
            self.fail(
                "svnmailer.notifier.stdout could not be imported: %s" %
                str(exc)
            )

_tests.append(importTestCase)


class StdoutNotifierTestCase(unittest.TestCase):
    """ svnmailer.notifier.stdout.StdoutNotifier """

    def setUp(self):
        """ Create test environment """
        from svnmailer.notifier import stdout
        self._stdout = stdout
        self._settings = Container(
            runtime = Container(),
            general = Container(),
            groups  = []
        )
        self._group = Container()

    def test00getOutputEnc(self):
        """ getOutputEnc returns a non-empty string """
        import sys, cStringIO

        mystdout = self._stdout.StdoutNotifier(
            self._settings,
            Container(groups = [self._group], changes = [], xchanges = [])
        )
        for fp in [sys.stdout, cStringIO.StringIO()]:
            result = mystdout._getOutputEnc(sys.stdout)
            self.failUnless(
                isinstance(result, str) and bool(result),
                "Doesn't return a non-empty string, but %r" % result
            )

    def test01writePreamble(self):
        """ writePreamble lists all groups """
        import cStringIO
        mystdout = self._stdout.StdoutNotifier(
            self._settings,
            Container(groups = [self._group], changes = [], xchanges = [])
        )
        mystdout.fp = cStringIO.StringIO()
        mystdout._writePreamble([
            Container(_name = u'g1'), Container(_name = u'g2')
        ])
        result = mystdout.fp.getvalue()
        mystdout.fp.close()

        self.failUnless(
            result.find(u"[g1]") >= 0 and result.find(u"[g2]") >= 0,
            "Doesn't list all groups, but writes %r" % result
        )

    def test02runMethod(self):
        """ run method writes the notification at all """
        import cStringIO

        class MyStdout(self._stdout.StdoutNotifier):
            _fp = cStringIO.StringIO()
            def _writePreamble(this, groups):
                this.fp.write("preamble - ")
            def _writeNotification(this):
                this.fp.write("notify")

        mystdout = MyStdout(
            self._settings,
            Container(groups = [self._group], changes = [], xchanges = [])
        )
        mystdout.run()

        result = mystdout._fp.getvalue()
        mystdout._fp.close()

        self.failUnlessEqual("preamble - notify", result,
            "Doesn't give the expected result, but %r" % result
        )

_tests.append(StdoutNotifierTestCase)


# dummy objects
# =============
class Container(object):
    def __init__(self, **kwargs):
        self._dict = kwargs
    def __getattr__(self, name):
        return self._dict.get(name)


#### Glue code                                      ####
########################################################
__all__.extend(_tests)

def getSuite():
    """ Returns the test suite for this module """
    return [_test.__name__ for _test in _tests]
